
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '33.5.0',
    'branch_nick': 'release-33',
    'revision_id': '3d4c7c5ec4a4fd63d86d72c9cbe0f03eb52f1130',
    'revno': 12712
}
